A command line interface and Python library for the Global Pathogen Analysis System

## Install (development)

```
# From a Python >= 3.10 venv
git clone https://github.com/GenomePathogenAnalysisService/gpas
cd gpas
pip install -e .
pytest
```